@@ -1,4 +1,4 @@
-cv.coxnet=function(outlist,lambda,x,y,weights,offset,foldid,type.measure,grouped){
+cv.coxnet=function(outlist,lambda,x,y,weights,offset,foldid,type.measure,grouped,keep){
   typenames=c("deviance"="Partial Likelihood Deviance")
   if(type.measure=="default")type.measure="deviance"
   if(!match(type.measure,c("deviance"),FALSE)){
@@ -38,5 +38,7 @@ cv.coxnet=function(outlist,lambda,x,y,weights,offset,foldid,type.measure,grouped
 
   cvm=apply(cvraw,2,weighted.mean,w=weights,na.rm=TRUE)
   cvsd=sqrt(apply(scale(cvraw,cvm,FALSE)^2,2,weighted.mean,w=weights,na.rm=TRUE)/(N-1))
-  list(cvm=cvm,cvsd=cvsd,name=typenames[type.measure])
+  out=list(cvm=cvm,cvsd=cvsd,name=typenames[type.measure])
+  if(keep)warning("keep=TRUE not implemented for coxnet")
+  out
 }
